@@ -1,7 +1,7 @@
 package App::TSVUtils;
 
-our $DATE = '2019-05-21'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2019-12-19'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -114,7 +114,7 @@ App::TSVUtils - CLI utilities related to TSV
 
 =head1 VERSION
 
-This document describes version 0.002 of App::TSVUtils (from Perl distribution App-TSVUtils), released on 2019-05-21.
+This document describes version 0.003 of App::TSVUtils (from Perl distribution App-TSVUtils), released on 2019-12-19.
 
 =head1 DESCRIPTION
 
@@ -184,10 +184,11 @@ feature.
 
 L<App::SerializeUtils>
 
-L<App::LTSVUtils> (which includes utilities like L<ltsv2tsv>, L<tsv2ltsv>, among
-others).
+L<App::LTSVUtils>, which includes utilities like L<ltsv2tsv>, L<tsv2ltsv>, among
+others.
 
-L<App::CSVUtils> (which includes L<csv2tsv>, L<tsv2csv> among others).
+L<App::CSVUtils>, which includes L<csv2tsv>, L<tsv2csv> among others. Scripts
+included in App::CSVUtils also support reading TSV via C<--tsv> flag.
 
 =head1 AUTHOR
 
